@@ -7,8 +7,6 @@ module System.PosixCompat.Internal.Time (
       ClockTime
     , getClockTime
     , clockTimeToEpochTime
-    , ModificationTime
-    , modificationTimeToEpochTime
     ) where
 
 import System.Posix.Types (EpochTime)
@@ -20,15 +18,9 @@ import System.Time (ClockTime(TOD), getClockTime)
 clockTimeToEpochTime :: ClockTime -> EpochTime
 clockTimeToEpochTime (TOD s _) = fromInteger s
 
-type ModificationTime = ClockTime
-
-modificationTimeToEpochTime :: ModificationTime -> EpochTime
-modificationTimeToEpochTime = clockTimeToEpochTime
-
 #else
 
-import Data.Time.Clock (UTCTime)
-import Data.Time.Clock.POSIX (POSIXTime, getPOSIXTime, utcTimeToPOSIXSeconds)
+import Data.Time.Clock.POSIX (POSIXTime, getPOSIXTime)
 
 type ClockTime = POSIXTime
 
@@ -38,9 +30,4 @@ getClockTime = getPOSIXTime
 clockTimeToEpochTime :: ClockTime -> EpochTime
 clockTimeToEpochTime = fromInteger . floor
 
-type ModificationTime = UTCTime
-
-modificationTimeToEpochTime :: UTCTime -> EpochTime
-modificationTimeToEpochTime = clockTimeToEpochTime . utcTimeToPOSIXSeconds
-
 #endif
